@@ -1,12 +1,7 @@
 effNames <-
 function (effects = NULL, loci = NULL, nloc = 1) 
 {
-    if (!exists("effectsNames")) {
-        effectsNames <- NULL
-        rm(effectsNames)
-        data(effectsNames, package = "noia")
-    }
-    n <- paste(rep(effectsNames[1], nloc), collapse = "")
+    n <- paste(rep(noia::effectsNames[1], nloc), collapse = "")
     if (!is.null(effects)) {
         for (i in 1:length(loci)) {
             substr(n, loci[i], loci[i] + 1) <- effects[i]
