@@ -1,4 +1,4 @@
-`gen2Z` <-
+gen2Z <-
 function (gen) 
 {
     return(genZ2Z(gen2genZ(gen)))
