@@ -1,4 +1,4 @@
-`print.noia.multilinear` <-
+print.noia.multilinear <-
 function (x, ...) 
 {
     print.noia.common(x, ...)
